/*-------------------------------------------------------------------------------
 This file is part of unityForest.

 unityForest is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 unityForest is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with unityForest. If not, see <http://www.gnu.org/licenses/>.

 This file is based on the ranger package.

 Original author:
   Marvin N. Wright
   Institut für Medizinische Biometrie und Statistik
   Universität zu Lübeck
   http://www.imbs-luebeck.de

 Modifications and extensions for the unityForest package:
   Roman Hornung
 #-------------------------------------------------------------------------------*/

#include "DataSparse.h"

namespace unityForest
{

  DataSparse::DataSparse(Eigen::SparseMatrix<double> &data, std::vector<std::string> variable_names, size_t num_rows,
                         size_t num_cols) : data{}
  {
    this->data.swap(data);
    this->variable_names = variable_names;
    this->num_rows = num_rows;
    this->num_cols = num_cols;
    this->num_cols_no_snp = num_cols;
  }

} // namespace unityForest
